<h1>👮‍♂️ MASZ API Wrapper</h1>
<p>
<img src="https://img.shields.io/pypi/pyversions/masz" />
<img src="https://img.shields.io/pypi/v/masz" />
<a href="https://github.com/zaanposni/masz-api-wrapper/blob/dev/LICENSE"><img src="https://img.shields.io/github/license/zaanposni/masz-api-wrapper.svg"/></a>
</p>

⭐ **Fully object-oriented library** to integrate the <a href="https://github.com/zaanposni/discord-masz" target="_blank">**MASZ API**</a> into your project.

## 🚀 Installation

**Python 3.6 or higher required**
```
pip install masz
```

## 👀Examples


## 🤝 Contributors <img src="https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat"/>

<a href="https://github.com/zaanposni"><img src="https://avatars3.githubusercontent.com/u/24491035?s=460&v=4"
                                            height=90px, width=90px style="border-radius: 50%" /></a>

## License:

This project is licensed under MIT.
